==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/fsx/kotlin/inputs/FileCacheLustreConfigurationLogConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.fsx.kotlin.inputs

import com.pulumi.aws.fsx.inputs.FileCacheLustreConfigurationLogConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property destination
 * @property level
 */
public data class FileCacheLustreConfigurationLogConfigurationArgs(
    public val destination: Output<String>? = null,
    public val level: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.fsx.inputs.FileCacheLustreConfigurationLogConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.fsx.inputs.FileCacheLustreConfigurationLogConfigurationArgs =
        com.pulumi.aws.fsx.inputs.FileCacheLustreConfigurationLogConfigurationArgs.builder()
            .destination(destination?.applyValue({ args0 -> args0 }))
            .level(level?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FileCacheLustreConfigurationLogConfigurationArgs].
 */
@PulumiTagMarker
public class FileCacheLustreConfigurationLogConfigurationArgsBuilder internal constructor() {
    private var destination: Output<String>? = null

    private var level: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("vfiatkaccdliqumy")
    public suspend fun destination(`value`: Output<String>) {
        this.destination = value
    }

    /**
     * @param value
     */
    @JvmName("txhoeciplbjdmirn")
    public suspend fun level(`value`: Output<String>) {
        this.level = value
    }

    /**
     * @param value
     */
    @JvmName("sveqxqnrqfxyqqnw")
    public suspend fun destination(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destination = mapped
    }

    /**
     * @param value
     */
    @JvmName("rxteeleetswknhsi")
    public suspend fun level(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.level = mapped
    }

    internal fun build(): FileCacheLustreConfigurationLogConfigurationArgs =
        FileCacheLustreConfigurationLogConfigurationArgs(
            destination = destination,
            level = level,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/fsx/kotlin/inputs/FileCacheLustreConfigurationLogConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.fsx.kotlin.inputs

import com.pulumi.aws.fsx.inputs.FileCacheLustreConfigurationLogConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property destination
 * @property level
 */
public data class FileCacheLustreConfigurationLogConfigurationArgs(
    public val destination: Output<String>? = null,
    public val level: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.fsx.inputs.FileCacheLustreConfigurationLogConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.fsx.inputs.FileCacheLustreConfigurationLogConfigurationArgs = com.pulumi.aws.fsx.inputs.FileCacheLustreConfigurationLogConfigurationArgs.builder()
        .destination(destination?.applyValue({ args0 -> args0 }))
        .level(level?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FileCacheLustreConfigurationLogConfigurationArgs].
 */
@PulumiTagMarker
public class FileCacheLustreConfigurationLogConfigurationArgsBuilder internal constructor() {
    private var destination: Output<String>? = null

    private var level: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("vapktndtrtnnxrra")
    public suspend fun destination(`value`: Output<String>) {
        this.destination = value
    }

    /**
     * @param value
     */
    @JvmName("mhnbqmfdbogpvskb")
    public suspend fun level(`value`: Output<String>) {
        this.level = value
    }

    /**
     * @param value
     */
    @JvmName("jyolthvphqjenjem")
    public suspend fun destination(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destination = mapped
    }

    /**
     * @param value
     */
    @JvmName("mgnogbbsyogypgus")
    public suspend fun level(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.level = mapped
    }

    internal fun build(): FileCacheLustreConfigurationLogConfigurationArgs =
        FileCacheLustreConfigurationLogConfigurationArgs(
            destination = destination,
            level = level,
        )
}
